Instinct

Enum Instinct 

pub enum Instinct {
Show 18 variants Survive, Flee, Defend, Guard, Perceive, Navigate, Report, Hoard, Rest, Cooperate, Communicate, Teach, Share, Learn, Curious, Explore, Mourn, Evolve,
}

Variants



Survive



Flee



Defend



Guard



Perceive



Navigate



Report



Hoard



Rest



Cooperate



Communicate



Teach



Share



Learn



Curious



Explore



Mourn



Evolve

Implementations

Source

impl Instinct

pub fn name(&self) -> &'static str

Human-readable name

pub fn source(&self) -> &'static str

Source system

pub fn all() -> &'static [Instinct]

All 18 instincts in priority order